pybet365.client package
=======================

Submodules
----------

pybet365.client.client module
-----------------------------

.. automodule:: pybet365.client.client
   :members:
   :undoc-members:
   :show-inheritance:

pybet365.client.config module
-----------------------------

.. automodule:: pybet365.client.config
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: pybet365.client
   :members:
   :undoc-members:
   :show-inheritance:
